X-Git-Url: https://git.xinqibao.xyz/dwm.git/blobdiff_plain/9ca5c3b108dbda55c1ac9f068b631911f5685eeb..e1deda9e040c052af62aecc2fb4ee770fb2496a2:/dwm.h?ds=inline

diff --git a/dwm.h b/dwm.h
index 8af071a..64ed4c7 100644
--- a/dwm.h
+++ b/dwm.h
@@ -1,4 +1,6 @@
-/* (C)opyright MMVI-MMVII Anselm R. Garbe <garbeam at gmail dot com>
+/* © 2006-2007 Anselm R. Garbe <garbeam at gmail dot com>
+ * © 2006-2007 Sander van Dijk <a dot h dot vandijk at gmail dot com>
+ * © 2007 Premysl Hruby <dfenze at gmail dot com>
  * See LICENSE file for license details.
  *
  * dynamic window manager is designed like any other X client as well. It is
@@ -36,10 +38,11 @@
 /* mask shorthands, used in event.c and client.c */
 #define BUTTONMASK		(ButtonPressMask | ButtonReleaseMask)
 
-enum { NetSupported, NetWMName, NetLast };		/* EWMH atoms */
-enum { WMProtocols, WMDelete, WMState, WMLast };	/* default atoms */
+enum { BarTop, BarBot, BarOff };			/* bar position */
 enum { CurNormal, CurResize, CurMove, CurLast };	/* cursor */
 enum { ColBorder, ColFG, ColBG, ColLast };		/* color */
+enum { NetSupported, NetWMName, NetLast };		/* EWMH atoms */
+enum { WMProtocols, WMDelete, WMState, WMLast };	/* default atoms */
 
 typedef struct Client Client;
 struct Client {
@@ -49,7 +52,7 @@ struct Client {
 	int basew, baseh, incw, inch, maxw, maxh, minw, minh;
 	int minax, maxax, minay, maxay;
 	long flags; 
-	unsigned int border;
+	unsigned int border, oldborder;
 	Bool isbanned, isfixed, ismax, isfloating;
 	Bool *tags;
 	Client *next;
@@ -82,7 +85,7 @@ extern const char *tags[];		/* all tags */
 char stext[256];			/* status text */
 int screen, sx, sy, sw, sh;		/* screen geometry */
 int wax, way, wah, waw;			/* windowarea geometry */
-unsigned int bh, blw;			/* bar height, bar layout label width */
+unsigned int bh, blw, bpos;		/* bar height, bar layout label width, bar position */
 unsigned int ntags, numlockmask;	/* number of tags, dynamic lock mask */
 void (*handler[LASTEvent])(XEvent *);	/* event handler */
 Atom wmatom[WMLast], netatom[NetLast];
@@ -98,13 +101,13 @@ Window root, barwin;
 void attach(Client *c);			/* attaches c to global client list */
 void configure(Client *c);		/* send synthetic configure event */
 void detach(Client *c);			/* detaches c from global client list */
-void focus(Client *c);			/* focus c, c may be NULL */
-void killclient(const char *arg);		/* kill c nicely */
+void focus(Client *c);			/* focus c if visible && !NULL, or focus top visible */
+void killclient(const char *arg);	/* kill sel  nicely */
 void manage(Window w, XWindowAttributes *wa);	/* manage new client */
 void resize(Client *c, int x, int y,
 		int w, int h, Bool sizehints);	/* resize with given coordinates c*/
-void togglefloating(const char *arg);	/* toggles focused client between floating/tiled state */
-void updatesizehints(Client *c);		/* update the size hint variables of c */
+void togglefloating(const char *arg);	/* toggles sel between floating/tiled state */
+void updatesizehints(Client *c);	/* update the size hint variables of c */
 void updatetitle(Client *c);		/* update the name of c */
 void unmanage(Client *c);		/* destroy c */
 
@@ -124,11 +127,13 @@ void incnmaster(const char *arg);	/* increments nmaster with arg's index value *
 void initlayouts(void);			/* initialize layout array */
 Client *nexttiled(Client *c);		/* returns tiled successor of c */
 void restack(void);			/* restores z layers of all clients */
-void setlayout(const char *arg);		/* sets layout, -1 toggles */
-void togglemax(const char *arg);		/* toggles maximization of floating client */
+void setlayout(const char *arg);	/* sets layout, NULL means next layout */
+void togglebar(const char *arg);	/* shows/hides the bar */
+void togglemax(const char *arg);	/* toggles maximization of floating client */
 void zoom(const char *arg);		/* zooms the focused client to master area, arg is ignored */
 
 /* main.c */
+void updatebarpos(void);		/* updates the bar position */
 void quit(const char *arg);		/* quit dwm nicely */
 int xerror(Display *dsply, XErrorEvent *ee);	/* dwm's X error handler */
 
@@ -136,8 +141,8 @@ int xerror(Display *dsply, XErrorEvent *ee);	/* dwm's X error handler */
 void compileregs(void);			/* initialize regexps of rules defined in config.h */
 Bool isvisible(Client *c);		/* returns True if client is visible */
 void settags(Client *c, Client *trans);	/* sets tags of c */
-void tag(const char *arg);		/* tags c with arg's index */
-void toggletag(const char *arg);		/* toggles c tags with arg's index */
+void tag(const char *arg);		/* tags sel with arg's index */
+void toggletag(const char *arg);	/* toggles sel tags with arg's index */
 void toggleview(const char *arg);	/* toggles the tag with arg's index (in)visible */
 void view(const char *arg);		/* views the tag with arg's index */